Constructing the Web Application
================================

Since we chose web platform for portability to various devices,
it is important that we design the web responsively.
The website was also designed to be as lightweight as possible,
so as to reduce the network throughput and the workload of
frontend devices.

There are also other considerations to take into account.

.. toctree::
   :maxdepth: 2

   suppl-spec
   choices
